# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: i4t/protobuf/Session.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pbose.protobuf import PbWK_pb2 as pbose_dot_protobuf_dot_PbWK__pb2
from pbose.protobuf import PbWS_pb2 as pbose_dot_protobuf_dot_PbWS__pb2
from i4t.protobuf import common_pb2 as i4t_dot_protobuf_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='i4t/protobuf/Session.proto',
  package='i4t.protobuf',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1ai4t/protobuf/Session.proto\x12\x0ci4t.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19pbose/protobuf/PbWK.proto\x1a\x19pbose/protobuf/PbWS.proto\x1a\x19i4t/protobuf/common.proto\"\xfd\x02\n\x12SessionTokenClaims\x12\x0b\n\x03iss\x18\x01 \x01(\t\x12\x0b\n\x03sub\x18\x02 \x01(\t\x12\x0b\n\x03\x61ud\x18\x03 \x01(\t\x12\'\n\x03\x65xp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03nbf\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03iat\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03jti\x18\x07 \x01(\t\x12\x0e\n\x06public\x18\x08 \x01(\x0c\x12\x0f\n\x07private\x18\t \x01(\x0c\x12\x35\n\x07session\x18\x0b \x01(\x0b\x32$.i4t.protobuf.ApplicationInformation\x12\x30\n\tauthority\x18\x0c \x01(\x0b\x32\x1d.i4t.protobuf.PeerInformation\x12.\n\x07\x63lients\x18\r \x03(\x0b\x32\x1d.i4t.protobuf.PeerInformation\"t\n\x0eSessionWarrant\x12\x0f\n\x07version\x18\x01 \x01(\r\x12#\n\x05token\x18\x02 \x01(\x0b\x32\x14.pbose.protobuf.PbWS\x12,\n\x0e\x65ncryption_key\x18\x03 \x01(\x0b\x32\x14.pbose.protobuf.PbWKb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,pbose_dot_protobuf_dot_PbWK__pb2.DESCRIPTOR,pbose_dot_protobuf_dot_PbWS__pb2.DESCRIPTOR,i4t_dot_protobuf_dot_common__pb2.DESCRIPTOR,])




_SESSIONTOKENCLAIMS = _descriptor.Descriptor(
  name='SessionTokenClaims',
  full_name='i4t.protobuf.SessionTokenClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iss', full_name='i4t.protobuf.SessionTokenClaims.iss', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub', full_name='i4t.protobuf.SessionTokenClaims.sub', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aud', full_name='i4t.protobuf.SessionTokenClaims.aud', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exp', full_name='i4t.protobuf.SessionTokenClaims.exp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nbf', full_name='i4t.protobuf.SessionTokenClaims.nbf', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iat', full_name='i4t.protobuf.SessionTokenClaims.iat', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jti', full_name='i4t.protobuf.SessionTokenClaims.jti', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public', full_name='i4t.protobuf.SessionTokenClaims.public', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private', full_name='i4t.protobuf.SessionTokenClaims.private', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session', full_name='i4t.protobuf.SessionTokenClaims.session', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authority', full_name='i4t.protobuf.SessionTokenClaims.authority', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clients', full_name='i4t.protobuf.SessionTokenClaims.clients', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=540,
)


_SESSIONWARRANT = _descriptor.Descriptor(
  name='SessionWarrant',
  full_name='i4t.protobuf.SessionWarrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='i4t.protobuf.SessionWarrant.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='i4t.protobuf.SessionWarrant.token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryption_key', full_name='i4t.protobuf.SessionWarrant.encryption_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=542,
  serialized_end=658,
)

_SESSIONTOKENCLAIMS.fields_by_name['exp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONTOKENCLAIMS.fields_by_name['nbf'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONTOKENCLAIMS.fields_by_name['iat'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONTOKENCLAIMS.fields_by_name['session'].message_type = i4t_dot_protobuf_dot_common__pb2._APPLICATIONINFORMATION
_SESSIONTOKENCLAIMS.fields_by_name['authority'].message_type = i4t_dot_protobuf_dot_common__pb2._PEERINFORMATION
_SESSIONTOKENCLAIMS.fields_by_name['clients'].message_type = i4t_dot_protobuf_dot_common__pb2._PEERINFORMATION
_SESSIONWARRANT.fields_by_name['token'].message_type = pbose_dot_protobuf_dot_PbWS__pb2._PBWS
_SESSIONWARRANT.fields_by_name['encryption_key'].message_type = pbose_dot_protobuf_dot_PbWK__pb2._PBWK
DESCRIPTOR.message_types_by_name['SessionTokenClaims'] = _SESSIONTOKENCLAIMS
DESCRIPTOR.message_types_by_name['SessionWarrant'] = _SESSIONWARRANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SessionTokenClaims = _reflection.GeneratedProtocolMessageType('SessionTokenClaims', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONTOKENCLAIMS,
  __module__ = 'i4t.protobuf.Session_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.SessionTokenClaims)
  ))
_sym_db.RegisterMessage(SessionTokenClaims)

SessionWarrant = _reflection.GeneratedProtocolMessageType('SessionWarrant', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONWARRANT,
  __module__ = 'i4t.protobuf.Session_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.SessionWarrant)
  ))
_sym_db.RegisterMessage(SessionWarrant)


# @@protoc_insertion_point(module_scope)
